@@ -1144,6 +1144,8 @@ init_async (GAsyncInitable *initable, int io_priority,
 	init_data = g_slice_new0 (NMObjectInitData);
 	init_data->object = self;
 	init_data->simple = g_simple_async_result_new (G_OBJECT (initable), callback, user_data, init_async);
+	if (cancellable)
+		g_simple_async_result_set_check_cancellable (init_data->simple, cancellable);
 	init_data->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
 
 	interfaces = g_dbus_object_get_interfaces (priv->object);
