@@ -157,6 +157,8 @@ nm_remote_connection_commit_changes_async (NMRemoteConnection *connection,
 
 	simple = g_simple_async_result_new (G_OBJECT (connection), callback, user_data,
 	                                    nm_remote_connection_commit_changes_async);
+	if (cancellable)
+		g_simple_async_result_set_check_cancellable (simple, cancellable);
 
 	settings = nm_connection_to_dbus (NM_CONNECTION (connection), NM_CONNECTION_SERIALIZE_ALL);
 	if (save_to_disk) {
@@ -273,6 +275,8 @@ nm_remote_connection_save_async (NMRemoteConnection *connection,
 
 	simple = g_simple_async_result_new (G_OBJECT (connection), callback, user_data,
 	                                    nm_remote_connection_save_async);
+	if (cancellable)
+		g_simple_async_result_set_check_cancellable (simple, cancellable);
 	nmdbus_settings_connection_call_save (priv->proxy, cancellable, save_cb, simple);
 }
 
@@ -371,6 +375,8 @@ nm_remote_connection_delete_async (NMRemoteConnection *connection,
 
 	simple = g_simple_async_result_new (G_OBJECT (connection), callback, user_data,
 	                                    nm_remote_connection_delete_async);
+	if (cancellable)
+		g_simple_async_result_set_check_cancellable (simple, cancellable);
 	nmdbus_settings_connection_call_delete (priv->proxy, cancellable, delete_cb, simple);
 }
 
@@ -483,6 +489,8 @@ nm_remote_connection_get_secrets_async (NMRemoteConnection *connection,
 
 	simple = g_simple_async_result_new (G_OBJECT (connection), callback, user_data,
 	                                    nm_remote_connection_get_secrets_async);
+	if (cancellable)
+		g_simple_async_result_set_check_cancellable (simple, cancellable);
 
 	nmdbus_settings_connection_call_get_secrets (priv->proxy,
 	                                             setting_name,
@@ -641,7 +649,7 @@ init_sync (GInitable *initable, GCancellable *cancellable, GError **error)
 	GVariant *settings;
 
 	priv->proxy = NMDBUS_SETTINGS_CONNECTION (_nm_object_get_proxy (NM_OBJECT (initable), NM_DBUS_INTERFACE_SETTINGS_CONNECTION));
-	g_signal_connect (priv->proxy, "updated", G_CALLBACK (updated_cb), initable);
+	g_signal_connect_object (priv->proxy, "updated", G_CALLBACK (updated_cb), initable, 0);
 
 	if (nmdbus_settings_connection_call_get_settings_sync (priv->proxy,
 	                                                       &settings,
@@ -724,14 +732,16 @@ init_async (GAsyncInitable *initable, int io_priority,
 	init_data->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
 	init_data->result = g_simple_async_result_new (G_OBJECT (initable), callback,
 	                                               user_data, init_async);
+	if (cancellable)
+		g_simple_async_result_set_check_cancellable (init_data->result, cancellable);
 	init_data->initable = initable;
 	init_data->io_priority = io_priority;
 
 	priv->proxy = NMDBUS_SETTINGS_CONNECTION (_nm_object_get_proxy (NM_OBJECT (initable),
 	                                          NM_DBUS_INTERFACE_SETTINGS_CONNECTION));
 
-	g_signal_connect (priv->proxy, "updated",
-	                  G_CALLBACK (updated_cb), initable);
+	g_signal_connect_object (priv->proxy, "updated",
+	                         G_CALLBACK (updated_cb), initable, 0);
 
 	nmdbus_settings_connection_call_get_settings (NM_REMOTE_CONNECTION_GET_PRIVATE (init_data->initable)->proxy,
 	                                              init_data->cancellable,
